(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs'), require('@angular/platform-browser'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('ngx-toasta', ['exports', '@angular/core', 'rxjs', '@angular/platform-browser', '@angular/common'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-toasta'] = {}, global.ng.core, global.rxjs, global.ng.platformBrowser, global.ng.common));
}(this, (function (exports, core, rxjs, platformBrowser, common) { 'use strict';

    /**
     * Check and return true if an object is type of string
     * @param obj Analyse has to object the string type
     * @return result of analysis
     */
    function isString(obj) {
        return typeof obj === 'string';
    }
    /**
     * Check and return true if an object is type of number
     * @param obj Analyse has to object the boolean type
     * @return result of analysis
     */
    function isNumber(obj) {
        return typeof obj === 'number';
    }
    /**
     * Check and return true if an object is type of Function
     * @param obj Analyse has to object the function type
     * @return result of analysis
     */
    function isFunction(obj) {
        return typeof obj === 'function';
    }

    /**
     * Options to configure a new Toast
     */
    var ToastOptions = /** @class */ (function () {
        function ToastOptions() {
        }
        return ToastOptions;
    }());
    ToastOptions.decorators = [
        { type: core.Injectable }
    ];
    /**
     * Structrure of a created Toast
     */
    var ToastData = /** @class */ (function () {
        function ToastData() {
        }
        return ToastData;
    }());
    ToastData.decorators = [
        { type: core.Injectable }
    ];
    /**
     * Default configuration for all toasts and toasta container
     */
    var ToastaConfig = /** @class */ (function () {
        function ToastaConfig() {
            // Maximum number of toasties to show at once
            this.limit = 5;
            // Whether to show the 'X' icon to close the toast
            this.showClose = true;
            // Whether to show a progress bar at the bottom of the notification
            this.showDuration = true;
            // The window position where the toast pops up
            this.position = 'bottom-right';
            // How long (in miliseconds) the toasta shows before it's removed. Set to null/0 to turn off.
            this.timeout = 5000;
            // What theme to use
            this.theme = 'default';
        }
        return ToastaConfig;
    }());
    ToastaConfig.decorators = [
        { type: core.Injectable }
    ];
    (function (ToastaEventType) {
        ToastaEventType[ToastaEventType["ADD"] = 0] = "ADD";
        ToastaEventType[ToastaEventType["CLEAR"] = 1] = "CLEAR";
        ToastaEventType[ToastaEventType["CLEAR_ALL"] = 2] = "CLEAR_ALL";
    })(exports.ToastaEventType || (exports.ToastaEventType = {}));
    var ToastaEvent = /** @class */ (function () {
        function ToastaEvent(type, value) {
            this.type = type;
            this.value = value;
        }
        return ToastaEvent;
    }());
    function toastaServiceFactory(config) {
        return new ToastaService(config);
    }
    /**
     * Toasta service helps create different kinds of Toasts
     */
    var ToastaService = /** @class */ (function () {
        function ToastaService(config) {
            this.config = config;
            // Init the counter
            this.uniqueCounter = 0;
            // ToastData event emitter
            // private toastsEmitter: EventEmitter<ToastData> = new EventEmitter<ToastData>();
            // Clear event emitter
            // private clearEmitter: EventEmitter<number> = new EventEmitter<number>();
            this.eventSource = new rxjs.Subject();
            this.events = this.eventSource.asObservable();
        }
        /**
         * Get list of toats
         */
        // getToasts(): Observable<ToastData> {
        //   return this.toastsEmitter.asObservable();
        // }
        // getClear(): Observable<number> {
        //   return this.clearEmitter.asObservable();
        // }
        /**
         * Create Toast of a default type
         */
        ToastaService.prototype.default = function (options) {
            this.add(options, 'default');
        };
        /**
         * Create Toast of info type
         * @param options Individual toasta config overrides
         */
        ToastaService.prototype.info = function (options) {
            this.add(options, 'info');
        };
        /**
         * Create Toast of success type
         * @param options Individual toasta config overrides
         */
        ToastaService.prototype.success = function (options) {
            this.add(options, 'success');
        };
        /**
         * Create Toast of wait type
         * @param options Individual toasta config overrides
         */
        ToastaService.prototype.wait = function (options) {
            this.add(options, 'wait');
        };
        /**
         * Create Toast of error type
         * @param options Individual toasta config overrides
         */
        ToastaService.prototype.error = function (options) {
            this.add(options, 'error');
        };
        /**
         * Create Toast of warning type
         * @param options Individual toasta config overrides
         */
        ToastaService.prototype.warning = function (options) {
            this.add(options, 'warning');
        };
        // Add a new toast item
        ToastaService.prototype.add = function (options, type) {
            var toastaOptions;
            if (isString(options) && options !== '' || isNumber(options)) {
                toastaOptions = {
                    title: options.toString()
                };
            }
            else {
                toastaOptions = options;
            }
            if (!toastaOptions || !toastaOptions.title && !toastaOptions.msg) {
                throw new Error('ngx-toasta: No toast title or message specified!');
            }
            type = type || 'default';
            // Set a unique counter for an id
            this.uniqueCounter++;
            // Set the local vs global config items
            var showClose = this._checkConfigItem(this.config, toastaOptions, 'showClose');
            // Set the local vs global config items
            var showDuration = this._checkConfigItem(this.config, toastaOptions, 'showDuration');
            // If we have a theme set, make sure it's a valid one
            var theme;
            if (toastaOptions.theme) {
                theme = ToastaService.THEMES.indexOf(toastaOptions.theme) > -1 ? toastaOptions.theme : this.config.theme;
            }
            else {
                theme = this.config.theme;
            }
            var toast = {
                id: this.uniqueCounter,
                title: toastaOptions.title,
                msg: toastaOptions.msg,
                showClose: showClose,
                showDuration: showDuration,
                type: 'toasta-type-' + type,
                theme: 'toasta-theme-' + theme,
                onAdd: toastaOptions.onAdd && isFunction(toastaOptions.onAdd) ? toastaOptions.onAdd : null,
                onRemove: toastaOptions.onRemove && isFunction(toastaOptions.onRemove) ? toastaOptions.onRemove : null
            };
            // If there's a timeout individually or globally, set the toast to timeout
            // Allows a caller to pass null/0 and override the default. Can also set the default to null/0 to turn off.
            toast.timeout = toastaOptions.hasOwnProperty('timeout') ? toastaOptions.timeout : this.config.timeout;
            // Push up a new toast item
            // this.toastsSubscriber.next(toast);
            // this.toastsEmitter.next(toast);
            this.emitEvent(new ToastaEvent(exports.ToastaEventType.ADD, toast));
            // If we have a onAdd function, call it here
            if (toastaOptions.onAdd && isFunction(toastaOptions.onAdd)) {
                toastaOptions.onAdd.call(this, toast);
            }
        };
        // Clear all toasts
        ToastaService.prototype.clearAll = function () {
            // this.clearEmitter.next(null);
            this.emitEvent(new ToastaEvent(exports.ToastaEventType.CLEAR_ALL));
        };
        // Clear the specific one
        ToastaService.prototype.clear = function (id) {
            // this.clearEmitter.next(id);
            this.emitEvent(new ToastaEvent(exports.ToastaEventType.CLEAR, id));
        };
        // Checks whether the local option is set, if not,
        // checks the global config
        ToastaService.prototype._checkConfigItem = function (config, options, property) {
            if (options[property] === false) {
                return false;
            }
            else if (!options[property]) {
                return config[property];
            }
            else {
                return true;
            }
        };
        ToastaService.prototype.emitEvent = function (event) {
            if (this.eventSource) {
                // Push up a new event
                this.eventSource.next(event);
            }
        };
        return ToastaService;
    }());
    // Allowed THEMES
    ToastaService.THEMES = ['default', 'material', 'bootstrap'];
    ToastaService.decorators = [
        { type: core.Injectable }
    ];
    ToastaService.ctorParameters = function () { return [
        { type: ToastaConfig }
    ]; };

    /**
     * Toasta is container for Toast components
     */
    var ToastaComponent = /** @class */ (function () {
        function ToastaComponent(config, toastaService) {
            this.config = config;
            this.toastaService = toastaService;
            this._position = '';
            // The storage for toasts.
            this.toasts = [];
            // Initialise position
            this.position = '';
        }
        Object.defineProperty(ToastaComponent.prototype, "position", {
            get: function () {
                return this._position;
            },
            // The window position where the toast pops up. Possible values:
            // - bottom-right (default value from ToastConfig)
            // - bottom-left
            // - bottom-center
            // - bottom-fullwidth
            // - top-right
            // - top-left
            // - top-center
            // - top-fullwidth
            // - center-center
            set: function (value) {
                if (value) {
                    var notFound = true;
                    for (var i = 0; i < ToastaComponent.POSITIONS.length; i++) {
                        if (ToastaComponent.POSITIONS[i] === value) {
                            notFound = false;
                            break;
                        }
                    }
                    if (notFound) {
                        // Position was wrong - clear it here to use the one from config.
                        value = this.config.position;
                    }
                }
                else {
                    value = this.config.position;
                }
                this._position = 'toasta-position-' + value;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * `ngOnInit` is called right after the directive's data-bound properties have been checked for the
         * first time, and before any of its children have been checked. It is invoked only once when the
         * directive is instantiated.
         */
        ToastaComponent.prototype.ngOnInit = function () {
            var _this = this;
            // We listen events from our service
            this.toastaService.events.subscribe(function (event) {
                if (event.type === exports.ToastaEventType.ADD) {
                    // Add the new one
                    var toast = event.value;
                    _this.add(toast);
                }
                else if (event.type === exports.ToastaEventType.CLEAR) {
                    // Clear the one by number
                    var id = event.value;
                    _this.clear(id);
                }
                else if (event.type === exports.ToastaEventType.CLEAR_ALL) {
                    // Lets clear all toasts
                    _this.clearAll();
                }
            });
        };
        /**
         * Event listener of 'closeToast' event comes from ToastaComponent.
         * This method removes ToastComponent assosiated with this Toast.
         */
        ToastaComponent.prototype.closeToast = function (toast) {
            this.clear(toast.id);
        };
        /**
         * Add new Toast
         */
        ToastaComponent.prototype.add = function (toast) {
            // If we've gone over our limit, remove the earliest
            // one from the array
            if (this.config.limit && this.toasts.length >= this.config.limit) {
                this.toasts.shift();
            }
            // Add toasta to array
            this.toasts.push(toast);
            //
            // If there's a timeout individually or globally,
            // set the toast to timeout
            if (+toast.timeout) {
                this._setTimeout(toast);
            }
        };
        /**
         * Clear individual toast by id
         * @param id is unique identifier of Toast
         */
        ToastaComponent.prototype.clear = function (id) {
            var _this = this;
            if (id) {
                this.toasts.forEach(function (value, key) {
                    if (value.id === id) {
                        if (value.onRemove && isFunction(value.onRemove)) {
                            value.onRemove.call(_this, value);
                        }
                        _this.toasts.splice(key, 1);
                    }
                });
            }
            else {
                throw new Error('Please provide id of Toast to close');
            }
        };
        /**
         * Clear all toasts
         */
        ToastaComponent.prototype.clearAll = function () {
            var _this = this;
            this.toasts.forEach(function (value, key) {
                if (value.onRemove && isFunction(value.onRemove)) {
                    value.onRemove.call(_this, value);
                }
            });
            this.toasts = [];
        };
        /**
         * Custom setTimeout function for specific setTimeouts on individual toasts.
         */
        ToastaComponent.prototype._setTimeout = function (toast) {
            var _this = this;
            window.setTimeout(function () {
                _this.clear(toast.id);
            }, toast.timeout);
        };
        return ToastaComponent;
    }());
    /**
     * Set of constants defines position of Toasta on the page.
     */
    ToastaComponent.POSITIONS = ['bottom-right', 'bottom-left', 'bottom-center', 'bottom-fullwidth', 'top-right', 'top-left', 'top-center', 'top-fullwidth', 'center-center'];
    ToastaComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ngx-toasta',
                    template: "\n    <div id=\"toasta\" [ngClass]=\"[position]\">\n        <ngx-toast *ngFor=\"let toast of toasts\" [toast]=\"toast\" (closeToast)=\"closeToast(toast)\"></ngx-toast>\n    </div>"
                },] }
    ];
    ToastaComponent.ctorParameters = function () { return [
        { type: ToastaConfig },
        { type: ToastaService }
    ]; };
    ToastaComponent.propDecorators = {
        position: [{ type: core.Input }]
    };

    /**
     * A Toast component shows message with title and close button.
     */
    var ToastComponent = /** @class */ (function () {
        function ToastComponent() {
            this.progressPercent = 0;
            this.startTime = performance.now();
            this.closeToastEvent = new core.EventEmitter();
        }
        ToastComponent.prototype.ngAfterViewInit = function () {
            var _this = this;
            if (this.toast.showDuration && this.toast.timeout > 0) {
                this.progressInterval = window.setInterval(function () {
                    _this.progressPercent = (100 - ((performance.now() - _this.startTime) / _this.toast.timeout * 100)); // Descending progress
                    if (_this.progressPercent <= 0) {
                        clearInterval(_this.progressInterval);
                    }
                }, 16.7); // 60 fps
            }
        };
        /**
         * Event handler invokes when user clicks on close button.
         * This method emit new event into ToastaContainer to close it.
         */
        ToastComponent.prototype.close = function ($event) {
            $event.preventDefault();
            this.closeToastEvent.next(this.toast);
            if (this.progressInterval) {
                clearInterval(this.progressInterval);
            }
        };
        return ToastComponent;
    }());
    ToastComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ngx-toast',
                    template: "\n        <div class=\"toast\" [ngClass]=\"[toast.type, toast.theme]\">\n            <div *ngIf=\"toast.showClose\" class=\"close-button\" (click)=\"close($event)\"></div>\n            <div *ngIf=\"toast.title || toast.msg\" class=\"toast-text\">\n                <span *ngIf=\"toast.title\" class=\"toast-title\" [innerHTML]=\"toast.title | safeHtml\"></span>\n                <br *ngIf=\"toast.title && toast.msg\" />\n                <span *ngIf=\"toast.msg\" class=\"toast-msg\" [innerHtml]=\"toast.msg | safeHtml\"></span>\n            </div>\n            <div class=\"durationbackground\" *ngIf=\"toast.showDuration && toast.timeout > 0\">\n                <div class=\"durationbar\" [style.width.%]=\"progressPercent\">\n                </div>\n            </div>\n        </div>"
                },] }
    ];
    ToastComponent.propDecorators = {
        toast: [{ type: core.Input }],
        closeToastEvent: [{ type: core.Output, args: ['closeToast',] }]
    };

    var SafeHtmlPipe = /** @class */ (function () {
        function SafeHtmlPipe(domSanitized) {
            this.domSanitized = domSanitized;
        }
        SafeHtmlPipe.prototype.transform = function (value) {
            var args = [];
            for (var _i = 1; _i < arguments.length; _i++) {
                args[_i - 1] = arguments[_i];
            }
            return this.domSanitized.bypassSecurityTrustHtml(value);
        };
        return SafeHtmlPipe;
    }());
    SafeHtmlPipe.decorators = [
        { type: core.Pipe, args: [{ name: 'safeHtml' },] }
    ];
    SafeHtmlPipe.ctorParameters = function () { return [
        { type: platformBrowser.DomSanitizer }
    ]; };

    var ɵ0 = toastaServiceFactory;
    var providers = [
        ToastaConfig,
        { provide: ToastaService, useFactory: ɵ0, deps: [ToastaConfig] }
    ];
    var ToastaModule = /** @class */ (function () {
        function ToastaModule() {
        }
        ToastaModule.forRoot = function () {
            return {
                ngModule: ToastaModule,
                providers: providers
            };
        };
        return ToastaModule;
    }());
    ToastaModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [common.CommonModule],
                    declarations: [ToastComponent, ToastaComponent, SafeHtmlPipe],
                    exports: [ToastComponent, ToastaComponent],
                    providers: providers
                },] }
    ];

    /*
     * Public API Surface of ngx-toasta
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.SafeHtmlPipe = SafeHtmlPipe;
    exports.ToastComponent = ToastComponent;
    exports.ToastData = ToastData;
    exports.ToastOptions = ToastOptions;
    exports.ToastaComponent = ToastaComponent;
    exports.ToastaConfig = ToastaConfig;
    exports.ToastaEvent = ToastaEvent;
    exports.ToastaModule = ToastaModule;
    exports.ToastaService = ToastaService;
    exports.providers = providers;
    exports.toastaServiceFactory = toastaServiceFactory;
    exports.ɵ0 = ɵ0;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-toasta.umd.js.map
